# Damm32

[![CircleCI](https://circleci.com/gh/trickeydan/damm32.svg?style=svg)](https://circleci.com/gh/trickeydan/damm32)

Python implementation of the Damm Algorithm in Base 32

By default, it uses an alphabet as specified in [RFC 4648](https://tools.ietf.org/html/rfc4648) which contains 32 alphanumeric characters, with similar looking characters removed. The padding symbol is not included.
